from typeguard import typeguard_ignore
from typeguard import install_import_hook

install_import_hook('testudo')
